@@ -1,7 +1,7 @@
-/* $Id: netperfmeter.cc 793 2010-11-17 15:08:10Z dreibh $
+/* $Id: netperfmeter.cc 939 2011-01-28 12:03:50Z dreibh $
  *
  * Network Performance Meter
- * Copyright (C) 2009-2010 by Thomas Dreibholz
+ * Copyright (C) 2009-2011 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,11 +35,6 @@
 #include "transfer.h"
 
 
-#ifndef HAVE_DCCP
-#warning DCCP is not supported by the API of this system!
-#endif
-
-
 using namespace std;
 
 
@@ -246,30 +241,38 @@ static const char* parseTrafficSpecOption(const char*      parameters,
       }
    }
    else if(strncmp(parameters, "cmt=", 4) == 0) {
-      if(strncmp((const char*)&parameters[4], "on", 2) == 0) {
-         trafficSpec.UseCMT = true;
+      unsigned int cmt;
+      int          pos;
+      if(strncmp((const char*)&parameters[4], "off", 3) == 0) {
+         trafficSpec.CMT = NPAF_PRIMARY_PATH;
+         n = 4 + 3;
+      }
+      else if(strncmp((const char*)&parameters[4], "normal", 6) == 0) {
+         trafficSpec.CMT = NPAF_CMT;
+         n = 4 + 6;
+      }
+      else if(strncmp((const char*)&parameters[4], "rp", 2) == 0) {
+         trafficSpec.CMT = NPAF_CMTRP;
          n = 4 + 2;
       }
-      else if(strncmp((const char*)&parameters[4], "off", 3) == 0) {
-         trafficSpec.UseCMT = false;
-         n = 4 + 3;
+      else if(sscanf((const char*)&parameters[4], "%u%n", &cmt, &pos) == 1) {
+         trafficSpec.CMT = cmt;
+         n = 4 + pos;
       }
       else {
          cerr << "ERROR: Invalid \"cmt\" setting: " << (const char*)&parameters[4] << "!" << std::endl;
          exit(1);
       }
    }
-   else if(strncmp(parameters, "rp=", 3) == 0) {
-      if(strncmp((const char*)&parameters[3], "on", 2) == 0) {
-         trafficSpec.UseRP = true;
-         n = 3 + 2;
-      }
-      else if(strncmp((const char*)&parameters[3], "off", 3) == 0) {
-         trafficSpec.UseRP = false;
-         n = 3 + 3;
+   else if(strncmp(parameters, "ccid=", 5) == 0) {
+      unsigned int ccid;
+      int          pos;
+      if(sscanf((const char*)&parameters[5], "%u%n", &ccid, &pos) == 1) {
+         trafficSpec.CCID = ccid;
+         n = 5 + pos;
       }
       else {
-         cerr << "ERROR: Invalid \"rp\" setting: " << (const char*)&parameters[4] << "!" << std::endl;
+         cerr << "ERROR: Invalid \"ccid\" setting: " << (const char*)&parameters[5] << "!" << std::endl;
          exit(1);
       }
    }
@@ -480,16 +483,7 @@ static Flow* createFlow(Flow*                  previousFlow,
          }
       }
 
-      int bufferSize = flow->getTrafficSpec().RcvBufferSize;
-      if(ext_setsockopt(socketDescriptor, SOL_SOCKET, SO_RCVBUF, &bufferSize, sizeof(bufferSize)) < 0) {
-         cerr << "ERROR: Failed to configure receive buffer size on SCTP socket (SO_RCVBUF option) - "
-              << strerror(errno) << "!" << endl;
-         exit(1);
-      }
-      bufferSize = flow->getTrafficSpec().SndBufferSize;
-      if(ext_setsockopt(socketDescriptor, SOL_SOCKET, SO_SNDBUF, &bufferSize, sizeof(bufferSize)) < 0) {
-         cerr << "ERROR: Failed to configure send buffer size on SCTP socket (SO_SNDBUF option) - "
-              << strerror(errno) << "!" << endl;
+      if(flow->configureSocket(socketDescriptor) == false) {
          exit(1);
       }
 
@@ -499,41 +493,6 @@ static Flow* createFlow(Flow*                  previousFlow,
          exit(1);
       }
 
-#ifdef SCTP_CMT_ON_OFF
-      struct sctp_assoc_value cmtOnOff;
-      cmtOnOff.assoc_id    = 0;
-      cmtOnOff.assoc_value = (flow->getTrafficSpec().UseCMT == true) ? 1 : 0;
-      if(ext_setsockopt(socketDescriptor, IPPROTO_SCTP, SCTP_CMT_ON_OFF, &cmtOnOff, sizeof(cmtOnOff)) < 0) {
-         if(flow->getTrafficSpec().UseCMT == true) {
-            cerr << "ERROR: Failed to configure CMT usage on SCTP socket (SCTP_CMT_ON_OFF option) - "
-                 << strerror(errno) << "!" << endl;
-            exit(1);
-         }
-      }
-#else
-      if(flow->getTrafficSpec().UseCMT == true) {
-         cerr << "ERROR: CMT usage configured, but not supported by this system!" << endl;
-         exit(1);
-      }
-#endif
-#ifdef SCTP_RP_ON_OFF
-      struct sctp_assoc_value rpOnOff;
-      rpOnOff.assoc_id    = 0;
-      rpOnOff.assoc_value = (flow->getTrafficSpec().UseRP == true) ? 1 : 0;
-      if(ext_setsockopt(socketDescriptor, IPPROTO_SCTP, SCTP_RP_ON_OFF, &rpOnOff, sizeof(rpOnOff)) < 0) {
-         if(flow->getTrafficSpec().UseRP == true) {
-            cerr << "ERROR: Failed to configure RP usage on SCTP socket (SCTP_RP_ON_OFF option) - "
-                 << strerror(errno) << "!" << endl;
-            exit(1);
-         }
-      }
-#else
-      if(flow->getTrafficSpec().UseRP == true) {
-         cerr << "ERROR: RP usage configured, but not supported by this system!" << endl;
-         exit(1);
-      }
-#endif
-
       if(gOutputVerbosity >= NPFOV_STATUS) {
          cout << "okay <sd=" << socketDescriptor << "> ";
       }
@@ -705,6 +664,12 @@ void passiveMode(int argc, char** argv, const uint16_t localPort)
    if(gDCCPSocket < 0) {
       cerr << "NOTE: Your kernel does not provide DCCP support." << endl;
    }
+   const uint32_t service[1] = { htonl(SC_NETPERFMETER_DATA) };
+   if(ext_setsockopt(gDCCPSocket, SOL_DCCP, DCCP_SOCKOPT_SERVICE, &service, sizeof(service)) < 0) {
+      std::cerr << "ERROR: Failed to configure DCCP service code on DCCP socket (DCCP_SOCKOPT_SERVICE option) - "
+               << strerror(errno) << "!" << std::endl;
+      exit(1);
+   }
 #endif
 
    gSCTPSocket = createAndBindSocket(AF_UNSPEC, SOCK_STREAM, IPPROTO_SCTP, localPort,
