@@ -1,7 +1,7 @@
-/* $Id: netperfmeterpackets.h 728 2010-08-31 08:02:50Z dreibh $
+/* $Id: netperfmeterpackets.h 939 2011-01-28 12:03:50Z dreibh $
  *
  * Network Performance Meter
- * Copyright (C) 2009-2010 by Thomas Dreibholz
+ * Copyright (C) 2009-2011 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ struct NetPerfMeterHeader
 
 #define PPID_NETPERFMETER_CONTROL   0x29097605
 #define PPID_NETPERFMETER_DATA      0x29097606
+#define SC_NETPERFMETER_DATA        0x29097606
 
 
 #define NETPERFMETER_ACKNOWLEDGE    0x01
@@ -93,15 +94,20 @@ struct NetPerfMeterAddFlowMessage
 
    uint16_t             MaxMsgSize;
 
-   uint16_t             Padding;
+   uint8_t              CMT;
+   uint8_t              CCID;
 
    uint16_t             OnOffEvents;
    uint32_t             OnOffEvent[];
 } __attribute__((packed));
 
 #define NPMAF_RTX_TRIALS_IN_MILLISECONDS (1 << 31)
-#define NPMAF_USE_CMT                    (1 << 30)
-#define NPMAF_USE_RP                     (1 << 29)
+#define NPMAF_USE_CMT                    (1 << 30)   /* DEPRECATED! */
+#define NPMAF_USE_RP                     (1 << 29)   /* DEPRECATED! */
+
+#define NPAF_PRIMARY_PATH 0x00
+#define NPAF_CMT          0x01
+#define NPAF_CMTRP        0x02
 
 
 struct NetPerfMeterRemoveFlowMessage
